@@ -16,8 +16,6 @@ from . import get_date_from_dataset_date, match_template
 
 logger = logging.getLogger(__name__)
 
-fixed_dataset_date = None
-
 
 class Read(Retrieve):
     """Read data from tabular source eg. csv, xls, xlsx
@@ -194,17 +192,14 @@ class Read(Retrieve):
             **kwargs,
         )
 
-    def read_hdx_metadata(
-        self, datasetinfo: MutableMapping, today: Optional[datetime] = None
-    ) -> Optional[Resource]:
-        """Read metadata from HDX dataset and add to input dictionary
+    def read_dataset(self, datasetinfo: MutableMapping) -> Dataset:
+        """Read HDX dataset
 
         Args:
             datasetinfo (MutableMapping): Dictionary of information about dataset
-            today (Optional[datetime]): Value to use for today. Defaults to None (datetime.now()).
 
         Returns:
-            Optional[Resource]: The resource if a url was not given
+            Dataset: The dataset that was read
         """
         dataset_name = datasetinfo["dataset"]
         saved_path = join(self.saved_dir, f"{dataset_name}.json")
@@ -216,6 +211,20 @@ class Read(Retrieve):
             if self.save:
                 logger.info(f"Saving dataset {dataset_name} in {saved_path}")
                 dataset.save_to_json(saved_path)
+        return dataset
+
+    def read_hdx_metadata(
+        self, datasetinfo: MutableMapping
+    ) -> Optional[Resource]:
+        """Read metadata from HDX dataset and add to input dictionary
+
+        Args:
+            datasetinfo (MutableMapping): Dictionary of information about dataset
+
+        Returns:
+            Optional[Resource]: The resource if a url was not given
+        """
+        dataset = self.read_dataset(datasetinfo)
         resource = None
         url = datasetinfo.get("url")
         if not url:
@@ -229,7 +238,7 @@ class Read(Retrieve):
                     break
             if not url:
                 raise ValueError(
-                    f"Cannot find {format} resource in {dataset_name}!"
+                    f"Cannot find {format} resource in {datasetinfo['dataset']}!"
                 )
             datasetinfo["url"] = url
         date = datasetinfo.get("source_date")
@@ -237,12 +246,9 @@ class Read(Retrieve):
             if isinstance(date, str):
                 datasetinfo["source_date"] = parse_date(date)
         else:
-            if fixed_dataset_date:
-                datasetinfo["source_date"] = fixed_dataset_date
-            else:
-                datasetinfo["source_date"] = get_date_from_dataset_date(
-                    dataset, today=today
-                )
+            datasetinfo["source_date"] = get_date_from_dataset_date(
+                dataset, today=self.today
+            )
         if "source" not in datasetinfo:
             datasetinfo["source"] = dataset["dataset_source"]
         if "source_url" not in datasetinfo:
