@@ -5,7 +5,7 @@ from hdx.scraper.base_scraper import BaseScraper
 from hdx.scraper.configurable.aggregator import Aggregator
 from hdx.scraper.runner import Runner
 
-from .conftest import check_scrapers, run_check_scraper, run_check_scrapers
+from .conftest import run_check_scraper, run_check_scrapers
 
 
 class TestScrapersAggregation:
@@ -44,7 +44,8 @@ class TestScrapersAggregation:
             ],
         )
 
-        adm_aggregation = {"AFG": ("ROAP",), "MMR": ("ROAP",)}
+        regions = ("ROAP",)
+        adm_aggregation = {"AFG": regions, "MMR": regions}
 
         configuration_hxl = configuration["aggregation_hxl"]
         level = "regional"
@@ -165,8 +166,7 @@ class TestScrapersAggregation:
             "https://covid19.who.int/WHO-COVID-19-global-data.csv",
             "https://data.humdata.org/organization/world-bank-group",
         ]
-        runner.run(names)
-        check_scrapers(
+        run_check_scrapers(
             names,
             runner,
             level,
@@ -176,8 +176,8 @@ class TestScrapersAggregation:
             source_urls=source_urls,
         )
 
-        level = "regional"
-        aggregator_configuration = configuration_hxl["aggregation_global"]
+        level = "global"
+        aggregator_configuration = configuration_hxl[f"aggregation_{level}"]
         adm_aggregation = ("AFG", "PSE")
         scrapers = Aggregator.get_scrapers(
             aggregator_configuration,
@@ -188,9 +188,9 @@ class TestScrapersAggregation:
         )
         names = runner.add_customs(scrapers, add_to_run=True)
         assert names == [
-            "population_regional",
-            "affected_infected_per100000_regional",
-            "affected_infected_perpop_regional",
+            f"population_{level}",
+            f"affected_infected_per100000_{level}",
+            f"affected_infected_perpop_{level}",
         ]
         pop = 42727060
         headers = (
@@ -210,7 +210,7 @@ class TestScrapersAggregation:
             values,
             list(),
             population_lookup=national_values[0] | {"global": pop},
-            source_urls=source_urls,
+            source_urls=list(),
         )
 
     def test_get_aggregation_nohxl(self, configuration, fallbacks):
@@ -371,8 +371,7 @@ class TestScrapersAggregation:
             "https://covid19.who.int/WHO-COVID-19-global-data.csv",
             "https://data.humdata.org/organization/world-bank-group",
         ]
-        runner.run(names)
-        check_scrapers(
+        run_check_scrapers(
             names,
             runner,
             level,
@@ -380,6 +379,7 @@ class TestScrapersAggregation:
             national_values,
             sources,
             source_urls=source_urls,
+            set_not_run=False,
         )
 
         level = "regional"
@@ -395,9 +395,9 @@ class TestScrapersAggregation:
         )
         names = runner.add_customs(scrapers, add_to_run=True)
         assert names == [
-            "population_regional",
-            "casesper100000_regional",
-            "casesperpopulation_regional",
+            f"population_{level}",
+            f"casesper100000_{level}",
+            f"casesperpopulation_{level}",
         ]
         pop = 42727060
         headers = (
@@ -416,6 +416,6 @@ class TestScrapersAggregation:
             headers,
             values,
             list(),
-            population_lookup=national_values[0] | {"global": pop},
+            population_lookup=national_values[0] | {"allregions": pop},
             source_urls=source_urls,
         )
